h5preserve is a thin wrapper around h5py_, inspired by camel_.

It can be installed via pip, but note that h5py_ requires a C compiler
and the hdf5_ library.

|Documentation Status| |Build Status| |Coverage Status|


.. |Documentation Status| image:: https://readthedocs.org/projects/h5preserve/badge/?version=latest
   :target: http://h5preserve.readthedocs.org/en/latest/?badge=latest
.. |Build Status| image:: https://travis-ci.org/aragilar/h5preserve.svg?branch=master
   :target: https://travis-ci.org/aragilar/h5preserve
.. |Coverage Status| image:: https://codecov.io/github/aragilar/h5preserve/coverage.svg?branch=master
   :target: https://codecov.io/github/aragilar/h5preserve?branch=master

.. _h5py: http://www.h5py.org/
.. _hdf5: https://www.hdfgroup.org/HDF5/
.. _camel: http://eev.ee/blog/2015/10/15/dont-use-pickle-use-camel/

